import { CliUx, Command, Config, HelpSection, Interfaces } from '@oclif/core';
import { AnyJson } from '@salesforce/ts-types';
import { Progress, Prompter, Spinner, Ux } from './ux';
export interface SfCommandInterface extends Interfaces.Command {
    configurationVariablesSection?: HelpSection;
    envVariablesSection?: HelpSection;
    errorCodes?: HelpSection;
}
/**
 * A base command that provides convenient access to CLI help
 * output formatting. Extend this command and set specific properties
 * to add help sections to the command's help output.
 *
 * @extends @oclif/core/command
 * @see https://github.com/oclif/core/blob/main/src/command.ts
 */
export declare abstract class SfCommand<T> extends Command {
    static enableJsonFlag: boolean;
    static configurationVariablesSection?: HelpSection;
    static envVariablesSection?: HelpSection;
    static errorCodes?: HelpSection;
    static tableFlags: typeof CliUx.Table.table.flags;
    spinner: Spinner;
    progress: Progress;
    private warnings;
    private ux;
    private prompter;
    constructor(argv: string[], config: Config);
    /**
     * Log warning to users. If --json is enabled, then the warning
     * will be added to the json output under the warnings property.
     */
    warn(input: SfCommand.Warning): SfCommand.Warning;
    /**
     * Warn user about sensitive information (access tokens, etc...) before
     * logging to the console.
     */
    logSensitive(msg?: string): void;
    /**
     * Display a table on the console. Will automatically be suppressed when --json flag is present.
     */
    table<R extends Ux.Table.Data>(data: R[], columns: Ux.Table.Columns<R>, options?: Ux.Table.Options): void;
    /**
     * Log a stylized url to the console. Will automatically be suppressed when --json flag is present.
     */
    url(text: string, uri: string, params?: {}): void;
    /**
     * Log stylized JSON to the console. Will automatically be suppressed when --json flag is present.
     */
    styledJSON(obj: AnyJson): void;
    /**
     * Log stylized object to the console. Will automatically be suppressed when --json flag is present.
     */
    styledObject(obj: AnyJson): void;
    /**
     * Prompt user for information. See https://www.npmjs.com/package/inquirer for more.
     *
     * This will NOT be automatically suppressed when the --json flag is present since we assume
     * that any command that prompts the user for required information will not also support the --json flag.
     *
     * If you need to conditionally suppress prompts to support json output, then do the following:
     *
     * @example
     * if (!this.jsonEnabled()) {
     *   await this.prompt();
     * }
     */
    prompt<R = Prompter.Answers>(questions: Prompter.Questions<R>, initialAnswers?: Partial<R>): Promise<R>;
    /**
     * Wrap the command result into the standardized JSON structure.
     */
    protected toSuccessJson(result: T): SfCommand.Json<T>;
    /**
     * Wrap the command error into the standardized JSON structure.
     */
    protected toErrorJson(error: Error): SfCommand.Error;
    abstract run(): Promise<T>;
}
export declare namespace SfCommand {
    type Warning = string | Error;
    interface Json<T> {
        status: number;
        result: T;
        warnings?: Warning[];
    }
    interface Error {
        status: number;
        name: string;
        message: string;
        stack: string | undefined;
        warnings?: Warning[];
    }
}
