"use strict";
/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateTableChoices = exports.Prompter = void 0;
const inquirer_1 = require("inquirer");
const ts_types_1 = require("@salesforce/ts-types");
class Prompter {
    /**
     * Prompt user for information. See https://www.npmjs.com/package/inquirer for more.
     */
    async prompt(questions, initialAnswers) {
        const answers = await inquirer_1.prompt(questions, initialAnswers);
        return answers;
    }
}
exports.Prompter = Prompter;
/**
 * Generate a formatted table for list and checkbox prompts
 *
 * Each option should contain the same keys as specified in columns.
 * For example,
 * const columns = { name: 'Name', type: 'Type', path: 'Path' };
 * const options = [{ name: 'foo', type: 'org', path: '/path/to/foo/' }];
 * generateTableChoices(columns, options);
 */
function generateTableChoices(columns, choices, 
// eslint-disable-next-line @typescript-eslint/no-unused-vars
padForCheckbox = true) {
    const columnEntries = Object.entries(columns);
    const columnLengths = columnEntries.map(([key, value]) => Math.max(ts_types_1.ensureString(value).length, ...choices.map((option) => ts_types_1.ensureString(option[key], `Type ${typeof option[key]} for ${key} in ${Object.keys(option).join(', ')}`)
        .length)) + 1);
    const choicesOptions = [
        new inquirer_1.Separator(`${padForCheckbox ? ' '.repeat(2) : ''}${columnEntries
            .map(([, value], index) => value === null || value === void 0 ? void 0 : value.padEnd(columnLengths[index], ' '))
            .join('')}`),
    ];
    for (const meta of choices) {
        const name = columnEntries
            .map(([key], index) => ts_types_1.ensureString(meta[key]).padEnd(columnLengths[index], ' '))
            .join('');
        const choice = { name, value: meta.value, short: ts_types_1.ensureString(meta.name) };
        choicesOptions.push(choice);
    }
    return choicesOptions;
}
exports.generateTableChoices = generateTableChoices;
//# sourceMappingURL=prompter.js.map